@@ -21,67 +21,69 @@ void dl_callback( GtkWidget *widget, gpointer callback_data );
 
 
 const char *err_msg[] = {
-	                        "An error has occured while forking",
-	                        "Cannot create pipe",
-	                        "Cannot open /dev/null",
-	                        "Memory allcation error has occurred",
-	                        "An error has occurred while trying to\nreopen a file as a stream (fdopen)",
-	                        "Cannot read from the pipe",
-	                        "Cannot delete file",
-	                        "Cannot open configuration file\nloading default values",
-	                        "Cannot create configuration file ~/.ripperXrc",
-	                        "Cannot open a pty\nMaybe all ptys are busy",
-	                        "/////  use perror msg until here /////",
-	                        "Too many arguments",
-	                        "Job already in progress",
-	                        "Please select a track to rip or encode. \nIf you did select tracks, they may already have been ripped.",
-	                        "Make sure an audio disc is in the drive and that you are \neither running ripperX as root, are a member\nof the \"cdrom\" group, or otherwise have appropriate\npermissions to access the CDROM device. \n\nError: cdparanoia complains:\n",
-	                        "The file name is too long",
-	                        "Some entry(s) are empty",
-	                        "An error has occurred while parsing ~/.ripperXrc",
-	                        "Some field(s) are empty. Subsituting default value",
-	                        "Invalid selection",
-	                        "Could not connect to CDDB server",
-	                        "Connection refused from CDDB server",
-	                        "CDDB Server Error",
-	                        "CD Not Found in CD Database",
-	                        "Cannot parse the format string",
-	                        "Plugin not present",
-	                        "Error while locking file.\nMake sure the WAV dir and MP3 dir paths are correct and \nyou have permission to write to those directories.",
-                            "The WAV dir is not writable.",
-                            "The MP3 dir is not writable.",
-                            "Cannot create WAV dir",
-                            "Cannot create MP3 dir",
-                        };
+	"An error has occured while forking",
+	"Cannot create pipe",
+	"Cannot open /dev/null",
+	"Memory allcation error has occurred",
+	"An error has occurred while trying to\nreopen a file as a stream (fdopen)",
+	"Cannot read from the pipe",
+	"Cannot delete file",
+	"Cannot open configuration file\nloading default values",
+	"Cannot create configuration file ~/.ripperXrc",
+	"Cannot open a pty\nMaybe all ptys are busy",
+	"/////  use perror msg until here /////",
+	"Too many arguments",
+	"Job already in progress",
+	"Please select a track to rip or encode. \nIf you did select tracks, they may already have been ripped.",
+	"Make sure an audio disc is in the drive and that you are \neither running ripperX as root, are a member\nof the \"cdrom\" group, or otherwise have appropriate\npermissions to access the CDROM device.\n",
+	"The file name is too long",
+	"Some entry(s) are empty",
+	"An error has occurred while parsing ~/.ripperXrc",
+	"Some field(s) are empty. Subsituting default value",
+	"Invalid selection",
+	"Could not connect to CDDB server",
+	"Connection refused from CDDB server",
+	"CDDB Server Error",
+	"CD Not Found in CD Database",
+	"Cannot parse the format string",
+	"Plugin not present",
+	"Error while locking file.\nMake sure the WAV dir and MP3 dir paths are correct and \nyou have permission to write to those directories.",
+	"The WAV dir is not writable.",
+	"The MP3 dir is not writable.",
+	"Cannot create WAV dir",
+	"Cannot create MP3 dir",
+	"Make sure an audio disc is in the CDROM device.",
+	"Make sure that you are a member of the the \"cdrom\" group,\nor otherwise have appropriate permissions to access the CDROM device.",
+};
 
 const struct {
 	char *title;
 	char *msg;
 } dialog_data[] = {
-    { "Abort confirmation",
-      "Do you really want to abort?" },
-    { "Wanna delete?",
-      "Do you want to delete current file?" },
-    { "Wanna overwrite?",
-      "The file already exists. Do you want to overwrite?" },
-    { "Enter file name",
-      "Enter new file name" },
-    { "Wanna create config file?" ,
-      "Config file ~/.ripperXrc does not exist.\nDo you want to create config file?" },
-    { "Low diskspace warning",
-      "There is less than 500 megabytes free on the wav partition.\n Do you want to continue?" },
-    {  "Low diskspace warning",
-       "There is less than 100 megabytes free on the mp3 partition.\n Do you want to continue?" },
-    {  "Directory does not exist",
-       "The WAV dir does not exist. Create it?" },
-    {  "Directory does not exist",
-       "The MP3 dir does not exist. Create it?" }
+	{ "Abort confirmation",
+		"Do you really want to abort?" },
+	{ "Wanna delete?",
+		"Do you want to delete current file?" },
+	{ "Wanna overwrite?",
+		"The file already exists. Do you want to overwrite?" },
+	{ "Enter file name",
+		"Enter new file name" },
+	{ "Wanna create config file?" ,
+		"Config file ~/.ripperXrc does not exist.\nDo you want to create config file?" },
+	{ "Low diskspace warning",
+		"There is less than 500 megabytes free on the wav partition.\n Do you want to continue?" },
+	{  "Low diskspace warning",
+		"There is less than 100 megabytes free on the mp3 partition.\n Do you want to continue?" },
+	{  "Directory does not exist",
+		"The WAV dir does not exist. Create it?" },
+	{  "Directory does not exist",
+		"The MP3 dir does not exist. Create it?" }
 };
 
 const char * status_msg [] = {
-	                             "Finished ripping",
-	                             "Finished encoding"
-                             };
+	"Finished ripping",
+	"Finished encoding"
+};
 
 void err_handler( int err_code, const char *extra_msg )
 {
@@ -92,8 +94,8 @@ void err_handler( int err_code, const char *extra_msg )
 	gtk_window_set_position( GTK_WINDOW( window ), GTK_WIN_POS_CENTER );
 	gtk_window_set_title( GTK_WINDOW( window ), "Error" );
 	gtk_signal_connect( GTK_OBJECT( window ), "destroy",
-	                    GTK_SIGNAL_FUNC( gtk_widget_destroyed ),
-	                    NULL );
+			GTK_SIGNAL_FUNC( gtk_widget_destroyed ),
+			NULL );
 	gtk_container_border_width( GTK_CONTAINER( window ), 5 );
 
 	vbox = gtk_vbox_new( FALSE, 3 );
@@ -125,6 +127,7 @@ void err_handler( int err_code, const char *extra_msg )
 	if ( extra_msg != NULL ) {
 		label = gtk_label_new( extra_msg );
 		gtk_label_set_justify( GTK_LABEL( label ), GTK_JUSTIFY_LEFT );
+		gtk_label_set_line_wrap( GTK_LABEL( label ), TRUE );
 		gtk_box_pack_start( GTK_BOX( vbox ), label, TRUE, FALSE, 0 );
 	}
 
@@ -134,8 +137,8 @@ void err_handler( int err_code, const char *extra_msg )
 	button = gtk_button_new_with_label( "Ok" );
 	GTK_WIDGET_SET_FLAGS( button, GTK_CAN_DEFAULT );
 	gtk_signal_connect_object( GTK_OBJECT( button ), "clicked",
-	                           GTK_SIGNAL_FUNC( gtk_widget_destroy ),
-	                           GTK_OBJECT( window ) );
+			GTK_SIGNAL_FUNC( gtk_widget_destroy ),
+			GTK_OBJECT( window ) );
 	gtk_box_pack_start( GTK_BOX( vbox ), button, TRUE, FALSE, 0 );
 	gtk_widget_grab_default( button );
 
