@@ -679,65 +679,66 @@ char* int2str( int integer )
 	return newstr;
 }
 
-long check_free_space(char* dir) {
-    FILE *file;
-    long len;
-    char cmd[MAX_FILE_NAME_LENGTH];
-    char buffer[MAX_FILE_NAME_LENGTH];
-    
-    snprintf(cmd, MAX_FILE_NAME_LENGTH - 1, "df -k '%s' |awk '{print $4}'", dir);
-    file = popen(cmd, "r");
-    fscanf(file, "%s\n", &buffer); /* read the Available title */
-    fscanf(file, "%ld", &len); /* now read the length */
-    pclose(file);
-    return len;
+long check_free_space(char* dir) 
+{
+	FILE *file;
+	long len;
+	char cmd[MAX_FILE_NAME_LENGTH];
+	char buffer[MAX_FILE_NAME_LENGTH];
+
+	snprintf(cmd, MAX_FILE_NAME_LENGTH - 1, "df -P '%s' 2>/dev/null | awk '{print $4}' | tail -1", dir);
+	file = popen(cmd, "r");
+	//fscanf(file, "%s\n", &buffer); /* read the Available title */
+	fscanf(file, "%ld", &len); /* now read the length */
+	pclose(file);
+	return len;
 }
 
 int check_dir(char *dir) {
-    int rc;
-    struct stat ds;
+	int rc;
+	struct stat ds;
 
-    rc = access(dir, F_OK);
-    if (rc != 0) {
-        return MISC_DOES_NOT_EXISTS;
-    }
-    rc = stat(dir, &ds);
-    if (rc != 0) {
-        return MISC_NOT_DIR;
-    } 
-    if (!S_ISDIR(ds.st_mode)) {
-        return MISC_NOT_DIR;
-    }
-    rc = access(dir, X_OK | W_OK | R_OK);
-    if (rc != 0) {
-        return MISC_NOT_WRITABLE;
-    }
-    return MISC_OK;
+	rc = access(dir, F_OK);
+	if (rc != 0) {
+		return MISC_DOES_NOT_EXISTS;
+	}
+	rc = stat(dir, &ds);
+	if (rc != 0) {
+		return MISC_NOT_DIR;
+	} 
+	if (!S_ISDIR(ds.st_mode)) {
+		return MISC_NOT_DIR;
+	}
+	rc = access(dir, X_OK | W_OK | R_OK);
+	if (rc != 0) {
+		return MISC_NOT_WRITABLE;
+	}
+	return MISC_OK;
 }
 
 int create_dir(char *path) {
-    char *parent;
-    char *tmp;
-    int rc;
+	char *parent;
+	char *tmp;
+	int rc;
 
-    tmp = strdup(path); /*preserve our string */
-    parent = dirname(tmp);
-    rc = check_dir(parent);
-    if (strcmp(parent, "/") == 0) {
-        return -1; /* stop endless loop */
-    }
-    if (rc == MISC_NOT_DIR || rc == MISC_NOT_WRITABLE) { 
-        return -1;
-    } else if (rc == MISC_DOES_NOT_EXISTS) {
-                /* recursively create */
-        if (create_dir(parent) != 0) {
-            fprintf(stderr, "failed to create %s\n", parent);
-            return -1;
-        }
-    }
-    rc = mkdir(path, 0755);
-    free(tmp);
-    return rc;
+	tmp = strdup(path); 	/* preserve our string */
+	parent = dirname(tmp);
+	rc = check_dir(parent);
+	if (strcmp(parent, "/") == 0) {
+		return -1; 	/* stop endless loop */
+	}
+	if (rc == MISC_NOT_DIR || rc == MISC_NOT_WRITABLE) { 
+		return -1;
+	} else if (rc == MISC_DOES_NOT_EXISTS) {
+		/* recursively create */
+		if (create_dir(parent) != 0) {
+			fprintf(stderr, "failed to create %s\n", parent);
+			return -1;
+		}
+	}
+	rc = mkdir(path, 0755);
+	free(tmp);
+	return rc;
 }
 
 int is_found(char *plugin) {
@@ -764,32 +765,32 @@ static char *wfext, *ecfext;
 
 void create_filenames_from_format(_main_data *main_data)
 {
-    int i;
+	int i;
 	static char *df;
-    
+
 	i = strlen(config.wav_path) - 1;
 	if (i >= 0 && config.wav_path[i] == '/')
 		config.wav_path[i] = 0;
 	i = strlen(config.mp3_path) - 1;
 	if (i >= 0 && config.mp3_path[i] == '/')
 		config.mp3_path[i] = 0;
-    if (config.cddb_config.make_directories && main_data->disc_title[0])
+	if (config.cddb_config.make_directories && main_data->disc_title[0])
 	{
-        parse_rx_format_string( &df,
-            config.cddb_config.dir_format_string, -1, NULL, NULL, 
-            main_data->disc_artist, main_data->disc_title, NULL );
-	  
-        remove_non_unix_chars( df );
+		parse_rx_format_string( &df,
+				config.cddb_config.dir_format_string, -1, NULL, NULL, 
+				main_data->disc_artist, main_data->disc_title, NULL );
+
+		remove_non_unix_chars( df );
 
 		mk_strcat(&wd, config.wav_path, "/", df, "/", NULL);
 		mk_strcat(&ed, config.mp3_path, "/", df, "/", NULL);
 
-        create_dir(wd);
-        create_dir(ed);
-    } else {
-        mk_strcat(&wd, config.wav_path, "/", NULL);
-        mk_strcat(&ed, config.mp3_path, "/", NULL);
-    }
+		create_dir(wd);
+		create_dir(ed);
+	} else {
+		mk_strcat(&wd, config.wav_path, "/", NULL);
+		mk_strcat(&ed, config.mp3_path, "/", NULL);
+	}
 
 	if ( config.auto_append_extension == TRUE ) {
 		wfext = ".wav";
@@ -804,8 +805,7 @@ void create_filenames_from_format(_main_data *main_data)
 		wfext = ecfext = "";
 }
 
-void create_file_names_for_track(_main_data *main_data, int track,
-								 char **wfp, char **efp)
+void create_file_names_for_track(_main_data *main_data, int track, char **wfp, char **efp)
 {
 	static char *buffer;
 	int rc;
