@@ -1,6 +1,8 @@
 
 #include <stdio.h>
 
+#include "id3.h"
+
 #include "misc_utils.h"
 #include "interface_common.h"
 #include "main_window_handler.h"
@@ -43,6 +45,18 @@ void sf_album_entry_changed( GtkWidget *widget, gpointer callback_data )
 	select_frame_handler( SF_ALBUM_ENTRY_CHG, 0, NULL );
 }
 
+// patch from M.Tyler
+// tm:  we're not quite read for this (need updates to cddb.c)
+//void sf_year_entry_changed( GtkWidget *widget, gpointer callback_data )
+//{
+//	select_frame_handler( SF_YEAR_ENTRY_CHG, 0, NULL );
+//}
+//
+//void sf_genre_entry_changed( GtkWidget *widget, gpointer callback_data )
+//{
+//	select_frame_handler( SF_GENRE_ENTRY_CHG, 0, NULL );
+//}
+
 void sf_filename_entry_changed( GtkWidget *widget, gpointer callback_data )
 {
 	int track;
@@ -81,6 +95,14 @@ void select_frame_handler( int ops, int track, _main_data *main_data )
 	static GtkWidget *artist_entry = NULL;
 	static GtkWidget *album_label = NULL;
 	static GtkWidget *album_entry = NULL;
+
+	//static GtkWidget *year_label = NULL;
+	//static GtkWidget *year_entry = NULL;
+	//static GtkWidget *genre_label = NULL;
+	//static GtkWidget *genre_entry = NULL;
+	//static GtkWidget *genre_combo = NULL;
+	//static GList *genre_combo_items = NULL;
+
 	static GtkWidget *filename_entry[ MAX_NUM_TRACK ];
 	static GtkWidget *rip_action_button = NULL;
 	static GtkWidget *encode_action_button = NULL;
@@ -194,6 +216,7 @@ void select_frame_handler( int ops, int track, _main_data *main_data )
 
 			/* artist and album entry fields */
 			hbox3 = gtk_hbox_new (FALSE, 0);
+
 			artist_label = gtk_label_new("Artist");
 			gtk_box_pack_start(GTK_BOX(hbox3), artist_label, FALSE, FALSE, 5);
 			artist_entry = gtk_entry_new_with_max_length(MAX_ARTIST_LENGTH);
@@ -202,6 +225,7 @@ void select_frame_handler( int ops, int track, _main_data *main_data )
 			                    GTK_SIGNAL_FUNC( sf_artist_entry_changed ),
 			                    NULL );
 			gtk_box_pack_start(GTK_BOX(hbox3), artist_entry, TRUE, TRUE, 5);
+
 			album_label = gtk_label_new("Album");
 			gtk_box_pack_start(GTK_BOX(hbox3), album_label, FALSE, FALSE, 5);
 			album_entry = gtk_entry_new_with_max_length(MAX_ARTIST_LENGTH);
@@ -210,6 +234,52 @@ void select_frame_handler( int ops, int track, _main_data *main_data )
 			                    GTK_SIGNAL_FUNC( sf_album_entry_changed ),
 			                    NULL );
 			gtk_box_pack_start(GTK_BOX(hbox3), album_entry, TRUE, TRUE, 5);
+
+//			year_label = gtk_label_new("Year");
+//			gtk_box_pack_start(GTK_BOX(hbox3), year_label, FALSE, FALSE, 5);
+//			year_entry = gtk_entry_new_with_max_length(MAX_YEAR_LENGTH);
+//			gtk_widget_set_usize(year_entry, 60, -2);
+//			if ( strlen(main_data->disc_year) < 2 )
+//				sprintf(main_data->disc_year, "2005");
+//			gtk_entry_set_text(GTK_ENTRY(year_entry), main_data->disc_year);
+//			gtk_signal_connect( GTK_OBJECT( year_entry ), "changed",
+//			                    GTK_SIGNAL_FUNC( sf_year_entry_changed ),
+//			                    NULL );
+//			gtk_box_pack_start(GTK_BOX(hbox3), year_entry, TRUE, TRUE, 5);
+//
+//			genre_label = gtk_label_new("Genre");
+//			gtk_box_pack_start(GTK_BOX(hbox3), genre_label, FALSE, FALSE, 5);
+//			genre_combo = gtk_combo_new ();
+//			gtk_widget_show (genre_combo);
+//			gtk_box_pack_start(GTK_BOX(hbox3), genre_combo, TRUE, TRUE, 5);
+//			gtk_widget_set_usize (genre_combo, 80, -2);
+//			gtk_container_set_border_width (GTK_CONTAINER (genre_combo), 5);
+//			gtk_combo_set_value_in_list (GTK_COMBO (genre_combo), TRUE, FALSE);
+//			gtk_combo_set_use_arrows_always (GTK_COMBO (genre_combo), TRUE);
+//
+//			i = 0;
+//			while ( id3_styles[i].name != NULL )
+//			{
+//				genre_combo_items = g_list_append (genre_combo_items,
+//							(gpointer) id3_styles[i].name);
+//				i++;
+//			}
+//			gtk_combo_set_popdown_strings (GTK_COMBO (genre_combo), genre_combo_items);
+//			g_list_free (genre_combo_items);
+//			genre_combo_items = NULL;
+//
+//			genre_entry = GTK_COMBO (genre_combo)->entry;
+//
+//			if ( strlen(main_data->disc_category) < 2 )
+//				sprintf(main_data->disc_category, "Pop");
+//
+//			gtk_entry_set_text (GTK_ENTRY (genre_entry), main_data->disc_category);
+//			gtk_signal_connect( GTK_OBJECT( genre_entry ), "changed",
+//			                    GTK_SIGNAL_FUNC( sf_genre_entry_changed ),
+//			                    NULL );
+//			gtk_widget_show (genre_entry);
+
+
 			gtk_box_pack_start(GTK_BOX(vbox2), hbox3, FALSE, FALSE, 5);
 			
 			/* the table */
@@ -334,6 +404,18 @@ void select_frame_handler( int ops, int track, _main_data *main_data )
 		        gtk_entry_get_text( GTK_ENTRY( album_entry ) ) );
 		return;
 
+//	case SF_YEAR_ENTRY_CHG :
+//		/* The album year has been edited. Sync saved album year */
+//		strcpy( saved_main_data->disc_year,
+//		        gtk_entry_get_text( GTK_ENTRY( year_entry ) ) );
+//		return;
+//
+//	case SF_GENRE_ENTRY_CHG :
+//		/* The album genre has been edited. Sync saved album genre */
+//		strcpy( saved_main_data->disc_category,
+//		        gtk_entry_get_text( GTK_ENTRY( genre_entry ) ) );
+//		return;
+
 	case SF_FILENAME_ENTRY_CHG :
 		if ( strlen( gtk_entry_get_text( GTK_ENTRY( filename_entry[ track ] ) ) ) == 0 ) {
 			if ( GTK_TOGGLE_BUTTON( track_selected_button[ track ] ) ->active == TRUE ) {
